@@ -44,16 +44,14 @@
 using namespace std;
 
 using aptitude::cmdline::create_terminal;
-using aptitude::cmdline::create_terminal_locale;
 using aptitude::cmdline::make_text_progress;
-using aptitude::cmdline::terminal;
+using aptitude::cmdline::terminal_io;
 using aptitude::cmdline::terminal_locale;
 using boost::shared_ptr;
 
 int cmdline_clean(int argc, char *argv[], bool simulate)
 {
-  const shared_ptr<terminal> term = create_terminal();
-  const shared_ptr<terminal_locale> term_locale = create_terminal_locale();
+  const shared_ptr<terminal_io> term = create_terminal();
 
   _error->DumpErrors();
 
@@ -63,7 +61,7 @@ int cmdline_clean(int argc, char *argv[], bool simulate)
       return -1;
     }  
 
-  shared_ptr<OpProgress> progress = make_text_progress(false, term, term_locale);
+  shared_ptr<OpProgress> progress = make_text_progress(false, term, term, term);
 
   apt_init(progress.get(), false);
 
@@ -137,8 +135,7 @@ public:
 
 int cmdline_autoclean(int argc, char *argv[], bool simulate)
 {
-  const shared_ptr<terminal> term = create_terminal();
-  const shared_ptr<terminal_locale> term_locale = create_terminal_locale();
+  const shared_ptr<terminal_io> term = create_terminal();
 
   _error->DumpErrors();
 
@@ -148,7 +145,7 @@ int cmdline_autoclean(int argc, char *argv[], bool simulate)
       return -1;
     }  
 
-  shared_ptr<OpProgress> progress = make_text_progress(false, term, term_locale);
+  shared_ptr<OpProgress> progress = make_text_progress(false, term, term, term);
 
   apt_init(progress.get(), false);
 
