@@ -62,7 +62,7 @@
 
 using namespace std;
 
-using aptitude::cmdline::terminal;
+using aptitude::cmdline::terminal_metrics;
 using boost::shared_ptr;
 
 typedef generic_solution<aptitude_universe> aptitude_solution;
@@ -216,7 +216,7 @@ static inline cw::fragment *flowindentbox(int i1, int irest, cw::fragment *f)
 }
 
 static void resolver_help(ostream &out,
-                          const shared_ptr<terminal> &term)
+                          const shared_ptr<terminal_metrics> &term_metrics)
 {
   cw::fragment *f=indentbox(2, 2,
 			cw::fragf(_("y: %F"
@@ -282,7 +282,7 @@ static void resolver_help(ostream &out,
 			      flowindentbox(0, 3,
 					    cw::fragf(_("Adjustments will cause the current solution to be discarded and recalculated as necessary.")))));
 
-  const unsigned int screen_width = term->get_screen_width();
+  const unsigned int screen_width = term_metrics->get_screen_width();
   out << f->layout(screen_width, screen_width, cwidget::style());
   delete f;
 }
@@ -527,7 +527,7 @@ static void reject_or_mandate_version(const string &s,
 
 void cmdline_resolver_show_choice(const choice &c,
 				  const std::string &tag,
-                                  const shared_ptr<terminal> &term)
+                                  const shared_ptr<terminal_metrics> &term_metrics)
 {
   cw::fragment *info_fragment = NULL;
   bool is_rejected = false;
@@ -616,7 +616,7 @@ void cmdline_resolver_show_choice(const choice &c,
 				// aren't translated.
                                             : cw::fragf(_("Enter \"a %s\" to require that new solutions include this action if possible."), tag.c_str()))));
 
-  const unsigned int screen_width = term->get_screen_width();
+  const unsigned int screen_width = term_metrics->get_screen_width();
   cwidget::fragment_contents lines = f->layout(screen_width, screen_width, cwidget::style());
 
   delete f;
@@ -806,7 +806,7 @@ static aptitude_solution wait_for_solution(cwidget::threads::box<cmdline_resolve
 }
 
 aptitude_solution calculate_current_solution(bool suppress_message,
-                                             const shared_ptr<terminal> &term)
+                                             const shared_ptr<terminal_metrics> &term_metrics)
 {
   const int step_limit = aptcfg->FindI(PACKAGE "::ProblemResolver::StepLimit", 5000);
   if(step_limit <= 0)
@@ -831,7 +831,7 @@ aptitude_solution calculate_current_solution(bool suppress_message,
     return resman->get_solution(resman->get_selected_solution(), 0);
 
 
-  cmdline_spinner spin(aptcfg->FindI("Quiet", 0), term);
+  cmdline_spinner spin(aptcfg->FindI("Quiet", 0), term_metrics);
 
   if(!suppress_message)
     std::cout << _("Resolving dependencies...") << std::endl;
@@ -856,7 +856,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		     int verbose,
 		     pkgPolicy &policy,
 		     bool arch_only,
-                     const shared_ptr<terminal> &term)
+                     const shared_ptr<terminal_metrics> &term_metrics)
 {
   bool story_is_default = aptcfg->FindB(PACKAGE "::CmdLine::Resolver-Show-Steps", false);
 
@@ -884,7 +884,7 @@ cmdline_resolve_deps(pkgset &to_install,
 	  {
 	    try
 	      {
-		aptitude_solution sol = calculate_current_solution(true, term);
+		aptitude_solution sol = calculate_current_solution(true, term_metrics);
 
 		if(_error->PendingError())
 		  _error->DumpErrors();
@@ -901,7 +901,7 @@ cmdline_resolve_deps(pkgset &to_install,
 						    : solution_fragment_with_ids(sol, ids),
 						  NULL);
 
-                    const unsigned int screen_width = term->get_screen_width();
+                    const unsigned int screen_width = term_metrics->get_screen_width();
 		    cwidget::fragment_contents lines=f->layout(screen_width, screen_width, cwidget::style());
 
 		    delete f;
@@ -926,7 +926,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		switch(toupper(response[loc]))
 		  {
 		  case 'Y':
-		    (*apt_cache_file)->apply_solution(calculate_current_solution(true, term), NULL);
+		    (*apt_cache_file)->apply_solution(calculate_current_solution(true, term_metrics), NULL);
 		    modified_pkgs=true;
 		    break;
 		  case 'N':
@@ -951,7 +951,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		      cw::fragment *f = story_is_default
 			? solution_story(sol, &ids)
 			: solution_fragment_with_ids(sol, ids);
-                      const unsigned int screen_width = term->get_screen_width();
+                      const unsigned int screen_width = term_metrics->get_screen_width();
 		      cout << f->layout(screen_width, screen_width,
 					cwidget::style()) << endl;
 		      delete f;
@@ -976,7 +976,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		    break;
 		  case '?':
 		    cout << _("The following commands are available:") << endl;
-		    resolver_help(cout, term);
+		    resolver_help(cout, term_metrics);
 		    break;
 		  case '+':
 		  case '-':
@@ -989,7 +989,7 @@ cmdline_resolve_deps(pkgset &to_install,
 					   to_install, to_hold,
 					   to_remove, to_purge, verbose,
 					   policy, arch_only, false,
-                                           term);
+                                           term_metrics);
 		      modified_pkgs=true;
 		    }
 		    break;
@@ -1029,12 +1029,12 @@ cmdline_resolve_deps(pkgset &to_install,
 		      if(found == ids.end())
 			{
 			  cout << _("Invalid response; please enter one of the following commands:") << endl;
-			  resolver_help(cout, term);
+			  resolver_help(cout, term_metrics);
 			}
 		      else
 			{
 			  const choice &c = found->second;
-			  cmdline_resolver_show_choice(c, first_word, term);
+			  cmdline_resolver_show_choice(c, first_word, term_metrics);
 			}
 		    }
 		    break;
@@ -1064,7 +1064,7 @@ cmdline_resolve_deps(pkgset &to_install,
 		      case 'Y':
 			try
 			  {
-			    calculate_current_solution(false, term);
+			    calculate_current_solution(false, term_metrics);
 			    done=true;
 			  }
 			catch(NoMoreTime)
@@ -1140,7 +1140,7 @@ namespace aptitude
   {
     // Implements the --show-resolver-actions command-line parameters.
     void show_resolver_actions(const generic_solution<aptitude_universe> &solution,
-                               const shared_ptr<terminal> &term)
+                               const shared_ptr<terminal_metrics> &term_metrics)
     {
       if(solution.get_choices().size() > 0)
 	{
@@ -1148,7 +1148,7 @@ namespace aptitude
 	  // separate the solution from this message..
 	  std::cout << std::endl;
 	  std::auto_ptr<cw::fragment> story(solution_story(solution, NULL));
-          const unsigned int screen_width = term->get_screen_width();
+          const unsigned int screen_width = term_metrics->get_screen_width();
 	  std::cout << story->layout(screen_width, screen_width, cwidget::style());
 	}
     }
@@ -1159,7 +1159,7 @@ namespace aptitude
                            bool no_new_installs,
                            bool no_new_upgrades,
                            bool show_story,
-                           const shared_ptr<terminal> &term)
+                           const shared_ptr<terminal_metrics> &term_metrics)
     {
       if(!resman->resolver_exists())
 	return true;
@@ -1174,14 +1174,14 @@ namespace aptitude
 					       boost::make_shared<cmdline_resolver_continuation>(boost::ref(retbox)),
 					       cmdline_resolver_trampoline);
 
-	  cmdline_spinner spin(aptcfg->FindI("Quiet", 0), term);
+	  cmdline_spinner spin(aptcfg->FindI("Quiet", 0), term_metrics);
 	  // TODO: maybe we should say "calculating upgrade" if we're
 	  // running safe-upgrade?
 	  std::cout << _("Resolving dependencies...") << std::endl;
 	  generic_solution<aptitude_universe> sol = wait_for_solution(retbox, spin);
 
 	  if(show_story)
-	    show_resolver_actions(sol, term);
+	    show_resolver_actions(sol, term_metrics);
 
 	  (*apt_cache_file)->apply_solution(sol, NULL);
 	}
