@@ -59,9 +59,13 @@
 
 namespace cw = cwidget;
 
+using aptitude::cmdline::create_cmdline_download_progress;
 using aptitude::cmdline::make_text_progress;
-using aptitude::cmdline::terminal;
+using aptitude::cmdline::terminal_input;
 using aptitude::cmdline::terminal_locale;
+using aptitude::cmdline::terminal_metrics;
+using aptitude::cmdline::terminal_output;
+using aptitude::controllers::acquire_download_progress;
 using boost::shared_ptr;
 
 namespace
@@ -109,9 +113,9 @@ void ui_solution_screen()
 }
 
 void cmdline_show_stringlist(strvector &items,
-                             const shared_ptr<terminal> &term)
+                             const shared_ptr<terminal_metrics> &term_metrics)
 {
-  const unsigned int screen_width = term->get_screen_width();
+  const unsigned int screen_width = term_metrics->get_screen_width();
 
   int loc=2;
 
@@ -133,14 +137,14 @@ void cmdline_show_stringlist(strvector &items,
 }
 
 void cmdline_show_pkglist(pkgvector &items,
-                          const shared_ptr<terminal> &term)
+                          const shared_ptr<terminal_metrics> &term_metrics)
 {
   strvector tmp;
 
   for(pkgvector::iterator i=items.begin(); i!=items.end(); ++i)
     tmp.push_back(i->Name());
 
-  cmdline_show_stringlist(tmp, term);
+  cmdline_show_stringlist(tmp, term_metrics);
 }
 
 pkgCache::VerIterator cmdline_find_ver(pkgCache::PkgIterator pkg,
@@ -319,7 +323,7 @@ namespace
   void show_stats_change(stats initial, stats final,
 			 bool show_all,
 			 bool show_unchanged,
-                         const shared_ptr<terminal> &term)
+                         const shared_ptr<terminal_metrics> &term_metrics)
   {
     using cw::fragf;
     using cw::util::ssprintf;
@@ -404,7 +408,7 @@ namespace
       {
 	cw::fragment *f = join_fragments(output_fragments, L"\n");
 
-        const unsigned int screen_width = term->get_screen_width();
+        const unsigned int screen_width = term_metrics->get_screen_width();
 	std::cout << f->layout(screen_width, screen_width, cw::style());
 	delete f;
       }
@@ -422,11 +426,13 @@ namespace
 
 download_manager::result cmdline_do_download(download_manager *m,
 					     int verbose,
-                                             const shared_ptr<terminal> &term,
-                                             const shared_ptr<terminal_locale> &term_locale)
+                                             const shared_ptr<terminal_input> &term_input,
+                                             const shared_ptr<terminal_locale> &term_locale,
+                                             const shared_ptr<terminal_metrics> &term_metrics,
+                                             const shared_ptr<terminal_output> &term_output)
 {
   stats initial_stats(0, 0, 0, std::set<std::string>());
-  shared_ptr<OpProgress> progress = make_text_progress(false, term, term_locale);
+  shared_ptr<OpProgress> progress = make_text_progress(false, term_locale, term_metrics, term_output);
 
   if(aptcfg->FindI("Quiet", 0) == 0)
     {
@@ -440,7 +446,13 @@ download_manager::result cmdline_do_download(download_manager *m,
       initial_stats = compute_apt_stats();
     }
 
-  std::auto_ptr<download_signal_log> log(gen_cmdline_download_progress(term));
+  std::pair<download_signal_log *, boost::shared_ptr<acquire_download_progress> >
+    progress_display = create_cmdline_download_progress(term_input,
+                                                        term_locale,
+                                                        term_metrics,
+                                                        term_output);
+
+  std::auto_ptr<download_signal_log> log(progress_display.first);
 
   // Dump errors here because prepare() might check for pending errors
   // and think something failed.
@@ -468,7 +480,7 @@ download_manager::result cmdline_do_download(download_manager *m,
       final_stats = compute_apt_stats();
       show_stats_change(initial_stats, final_stats,
 			verbose >= 1, verbose >= 2,
-                        term);
+                        term_metrics);
     }
 
   return finish_res;
