@@ -1,6 +1,6 @@
 // main.cc  (neé testscr.cc)
 //
-//  Copyright 1999-2010 Daniel Burrows
+//  Copyright 1999-2011 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -42,11 +42,16 @@
 
 #include <generic/util/logging.h>
 #include <generic/util/temp.h>
+#include <generic/util/util.h>
 
 #ifdef HAVE_GTK
 #include <gtkmm.h>
 #endif
 
+#ifdef HAVE_QT
+#include <QtCore/qglobal.h> // To get the Qt version number
+#endif
+
 #include <cwidget/config/keybindings.h>
 #include <cwidget/generic/util/transcode.h>
 #include <cwidget/toplevel.h>
@@ -77,12 +82,17 @@
 #include <apt-pkg/init.h>
 
 #include <boost/format.hpp>
+#include <boost/optional.hpp>
 
 #ifdef HAVE_GTK
 #include "gtk/gui.h"
 #include "gtk/init.h"
 #endif
 
+#ifdef HAVE_QT
+#include "qt/qt_main.h"
+#endif
+
 #include <fstream>
 
 #include "loggers.h"
@@ -96,6 +106,8 @@ namespace cw = cwidget;
 
 using aptitude::Loggers;
 
+using boost::optional;
+
 using logging::DEBUG_LEVEL;
 using logging::ERROR_LEVEL;
 using logging::FATAL_LEVEL;
@@ -163,7 +175,12 @@ static void show_version()
 #else
   printf(_("  Gtk+ support disabled.\n"));
 #endif
-
+#ifdef HAVE_QT
+  printf(_("  Compiled with Qt 4.6.2 %s\n"), QT_VERSION_STR);
+  printf(_("  Running on Qt 4.6.2 %s\n"), qVersion());
+#else
+  printf(_("  Qt support disabled.\n"));
+#endif
   printf("%s", _("\nCurrent library versions:\n"));
   printf(_("  NCurses version: %s\n"), curses_version());
   printf(_("  cwidget version: %s\n"), cwidget::version().c_str());
@@ -210,6 +227,10 @@ static void usage()
   printf(_(" --gui          Use the GTK GUI even if disabled in the configuration.\n"));
 #endif
   printf(_(" --no-gui       Do not use the GTK GUI even if available.\n"));
+#ifdef HAVE_QT
+  printf(_(" --qt           Use the Qt GUI.\n"));
+  printf(_(" --no-qt        Do not use the Qt GUI even if enabled in the configuration.\n"));
+#endif
   printf(_(" -s             Simulate actions, but do not actually perform them.\n"));
   printf(_(" -d             Only download packages, do not install or remove anything.\n"));
   printf(_(" -P             Always prompt for confirmation or actions.\n"));
@@ -261,6 +282,8 @@ enum {
   OPTION_DISABLE_COLUMNS,
   OPTION_GUI,
   OPTION_NO_GUI,
+  OPTION_QT_GUI,
+  OPTION_NO_QT_GUI,
   OPTION_LOG_LEVEL,
   OPTION_LOG_FILE,
   OPTION_LOG_CONFIG_FILE,
@@ -315,6 +338,10 @@ option opts[]={
   {"gui", 0, &getopt_result, OPTION_GUI},
 #endif
   {"no-gui", 0, &getopt_result, OPTION_NO_GUI},
+#ifdef HAVE_QT
+  {"qt", 0, &getopt_result, OPTION_QT_GUI},
+  {"no-qt", 0, &getopt_result, OPTION_NO_QT_GUI},
+#endif
   {"log-level", 1, &getopt_result, OPTION_LOG_LEVEL},
   {"log-file", 1, &getopt_result, OPTION_LOG_FILE},
   {"log-config-file", 1, &getopt_result, OPTION_LOG_CONFIG_FILE},
@@ -437,7 +464,7 @@ namespace
 	logger_name = std::string(s, 0, colon_loc);
       }
 
-    log_level level;
+    optional<log_level> level;
 
     log_level_map::const_iterator found =
       log_levels.find(level_name);
@@ -462,7 +489,7 @@ namespace
 	return;
       }
 
-    targetLogger->setLevel(level);
+    targetLogger->setLevel(*level);
   }
 
   /** \brief Apply logging levels from the configuration file. */
@@ -518,7 +545,15 @@ void do_message_logged(std::ostream &out,
                        LoggerPtr logger,
                        const std::string &msg)
 {
-  out << sourceFilename << ":" << sourceLineNumber
+  time_t current_time = 0;
+  struct tm local_current_time;
+
+  time(&current_time);
+  localtime_r(&current_time, &local_current_time);
+
+  out << sstrftime("%F %T", &local_current_time)
+      << " [" << pthread_self() << "] "
+      << sourceFilename << ":" << sourceLineNumber
       << " " << describe_log_level(level)
       << " " << logger->getCategory()
       << " - " << msg << std::endl << std::flush;
@@ -651,9 +686,14 @@ int main(int argc, char *argv[])
 
 #ifdef HAVE_GTK
   // TODO: this should be a configuration option.
-  bool gui = aptcfg->FindB(PACKAGE "::Start-Gui", true);
+  bool use_gtk_gui = aptcfg->FindB(PACKAGE "::Start-Gui", true);
   // Use the in-progress new GUI harness instead of the old code.
-  bool use_new_gui = false;
+  bool use_new_gtk_gui = false;
+#endif
+
+#ifdef HAVE_QT
+  // Use Qt frontend.
+  bool use_qt_gui = false;
 #endif
 
   int curopt;
@@ -890,10 +930,10 @@ int main(int argc, char *argv[])
 	      break;
 #ifdef HAVE_GTK
 	    case OPTION_GUI:
-	      gui = true;
+	      use_gtk_gui = true;
 	      break;
 	    case OPTION_NO_GUI:
-	      gui = false;
+	      use_gtk_gui = false;
 	      break;
 #else
 	    case OPTION_NO_GUI:
@@ -935,10 +975,18 @@ int main(int argc, char *argv[])
 
             case OPTION_NEW_GUI:
 #ifdef HAVE_GTK
-              use_new_gui = true;
+              use_new_gtk_gui = true;
 #endif
               break;
+#ifdef HAVE_QT
+	    case OPTION_QT_GUI:
+	      use_qt_gui = true;
+	      break;
 
+	    case OPTION_NO_QT_GUI:
+	      use_qt_gui = false;
+	      break;
+#endif
 	    default:
 	      fprintf(stderr, "%s",
 		      _("WEIRDNESS: unknown option code received\n"));
@@ -1059,7 +1107,7 @@ int main(int argc, char *argv[])
 	{
 	  // Connect up the "please consume errors" routine for the
 	  // command-line.
-	  consume_errors.connect(sigc::mem_fun(_error, &GlobalError::DumpErrors));
+	  consume_errors.connect(sigc::mem_fun(_error, (void (GlobalError::*)()) &GlobalError::DumpErrors));
 
 	  if(update_only || install_only || autoclean_only || clean_only)
 	    {
@@ -1196,10 +1244,22 @@ int main(int argc, char *argv[])
 	}
     }
 
-#ifdef HAVE_GTK
-  if(gui)
+#ifdef HAVE_QT
+  if(use_qt_gui)
     {
-      if(use_new_gui)
+      if(aptitude::gui::qt::main(argc, argv))
+        return 0;
+
+      // Otherwise, fall back to trying to start a curses interface
+      // (assume that we can't contact the X server, or maybe that we
+      // can't load the UI definition)
+    }
+#endif
+
+#ifdef HAVE_GTK
+  if(use_gtk_gui)
+    {
+      if(use_new_gtk_gui)
         {
           if(gui::init(argc, argv))
             return 0;
