@@ -1,6 +1,6 @@
 // pkg_info_screen.cc
 //
-//  Copyright 2000-2002, 2004-2005, 2007 Daniel Burrows
+//  Copyright 2000-2002, 2004-2005, 2007-2008 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -26,10 +26,11 @@
 #include "pkg_info_screen.h"
 
 #include <cwidget/fragment.h>
+#include <cwidget/generic/util/ssprintf.h>
 #include <cwidget/widgets/layout_item.h>
 
 #include "dep_item.h"
-#include "desc_parse.h"
+#include "desc_render.h"
 #include "pkg_item_with_subtree.h"
 #include "pkg_subtree.h"
 #include "pkg_ver_item.h"
@@ -143,7 +144,10 @@ void pkg_grouppolicy_info::setup_package_info(const pkgCache::PkgIterator &pkg,
 	  pkg_subtree *prvtree=new pkg_subtree(cw::util::transcode(buf));
 
 	  for(pkgCache::PrvIterator prv=ver.ProvidesList(); !prv.end(); ++prv)
-	    prvtree->add_child(new pkg_item(prv.ParentPkg(), sig));
+	    {
+	      prvtree->add_child(new pkg_item(prv.ParentPkg(), sig));
+	      prvtree->inc_num_packages();
+	    }
 
 	  tree->add_child(prvtree);
 	}
@@ -154,7 +158,8 @@ void pkg_grouppolicy_info::setup_package_info(const pkgCache::PkgIterator &pkg,
   setup_package_deps<pkg_subtree>(pkg, ver, revtree, sig, true);
   tree->add_child(revtree);
 
-  pkg_vertree_generic *newtree=new pkg_vertree_generic(W_("Versions"), true);
+  pkg_vertree_generic *newtree =
+    new pkg_vertree_generic(cw::util::swsprintf(W_("Versions of %s").c_str(), pkg.Name()), true);
   setup_package_versions(pkg, newtree, sig);
   tree->add_child(newtree);
 }
